# Data Quality Auditor

[![Documentation Status](https://readthedocs.org/projects/qassure/badge/?version=latest)](https://qassure.readthedocs.io/en/latest/?badge=latest)

This module provides a useful base for anyone looking to audit data structure to ensure their 
conformance with a given specification. It allows for the creation of a report of all the 
deficiencies within a file and provides an easy-to-read framework for creating tests.

Read the [full documentation](https://qassure.readthedocs.io/en/latest/) for more details.
